#
# spec file for package cgdb
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cgdb
Version:        0.6.8
Release:        4.3
Summary:        Curses debugger
License:        GPL-2.0+
Group:          Development/Tools/Debuggers
Url:            http://cgdb.github.io/
Source0:        http://cgdb.me/files/%{name}-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  help2man
BuildRequires:  makeinfo
BuildRequires:  ncurses-devel
BuildRequires:  readline-devel
Requires:       gdb
Requires(preun): %{install_info_prereq}
Requires(post):  %{install_info_prereq}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CGDB is a curses (terminal-based) interface to the GNU Debugger (GDB). Its goal
is to be lightweight and responsive; not encumbered with unnecessary features.

The primary feature of CGDB is the constant presence of a source display,
updated as the program executes, to help keep you focused while debugging. The
interface is inspired by the classic Unix text editor, vi. Those familiar with
vi (or vim) should feel right at home using CGDB.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%defattr(-,root,root)
%doc TODO AUTHORS COPYING NEWS README
%{_bindir}/cgdb
%{_datadir}/cgdb/cgdb.txt
%{_mandir}/man1/cgdb.1.gz
%{_infodir}/cgdb.info.gz
%{_datadir}/cgdb

%changelog
* Thu Apr  2 2015 mpluskal@suse.com
- Update project and download url
- Update dependencies
- Cleanup spec file with spec-cleaner
- Update to 0.6.8
  * Fix issue #40, the map commands were adding additional new lines
    to the mappings. For instance, 'imap a b' in the ~/.cgdb/cgdbrc
    file would cause a to map to 'b<cr>' instead of just 'b'.
  * Added feature from issue #29, added 'until' command to CGDB.
  * Updated autotools configuration files to satisfy warnings and
    recommendations produced by autotools when run.
  * Fix issue #49, a gcc compiler warning.
  * Fixed a hang consuming 100%% CPU usage on OS X Mavericks (github #48).
  * Fixed a hang when quitting cgdb while inferior is running
    (github #1 and #5 and #46). This was believed to be fixed in the last
    release but I've finally reproduced the issue and fixed it for good.
* Fri Jun 14 2013 nevion@gmail.com
-update to 0.6.7
  - Changed documentation license from GFDL to GPL (github #6).
  - Fixed a hang on MacOS when quitting cgdb while inferior is
    running (github #1 and #5).
  - Fixed a crash when pressing 'n' in source window (github #5).
  - Fixed a bug opening files (and toggling breakpoints in files)
    with special characters (e.g. space) in their names.
* Tue Feb 14 2012 puzel@suse.com
- fix build on sle11-sp1
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Sep  7 2011 puzel@suse.com
- update to cgdb-0.6.6
  - Fixed a segfault on 64-bit systems in rline.c due to a missing
    prototype of cgdb_malloc. Thanks to Pietro Cerutti for
    reporting and diagnosing this one!
  - Fixed a bug in the file dialog. When searching for a file, and
    you hit enter to select it, CGDB would sometimes skip to the
    next file that matches and open that file instead.
  - No longer set the prompt to (gdb) on startup.
* Wed Dec 22 2010 puzel@novell.com
- clean up specfile
* Wed May 26 2010 puzel@novell.com
- require gdb
* Mon Jan  4 2010 puzel@novell.com
- update to cgdb-0.6.5
  * Turn autosourcereload to on by default. This matches GDB's
    behavior.
  * Add support for :up and :down in the cgdb status bar.
    Thanks Benoit Pierre for reporting this.
  * Enhanced tgdb in a2 mode. It now understands GNAT's
    pre-instance-choice, instance-choice, post-instance-choice
  extension.
  * Made searching and :commands a little more vi-like. If you abort a
    search, you can still recall the last search with 'n' or 'N'.
  If you backspace to the beginning of the line, a :command
  or /search is aborted.
  * Added some new cgdb commands.
    :c is now a synonym for :continue
    :f is now a synonym for :finish
    :n is now a synonym for :next
    :r is not a synonym for :run
    :s is now a synonym for :step
    :start is a new command that will send "start" to the debugger
    :kill is a new command that will send "kill" to the debugger
  * Shortcut mode has been removed from cgdb. If you liked it, you can
    put these commands in your cgdbrc file,
    map r :run<CR>
    map c :continue<CR>
    map f :finish<CR>
    map n :next<CR>
    map s :step<CR>
    and you will get the same functionality. Do not forget that,
    F5 is the same as 'run'.
    F6 is the same as 'continue'.
    F7 is the same as 'finish'.
    F8 is the same as 'next'.
    F10 is the same as 'step'.
    are always available.
  * Added a feature to CGDB which allows it to ask readline what key
    sequence it uses for the Home and End keys. That way, if the terminfo
    database is wrong, but the OS vendor modified /etc/inputrc, CGDB will
    have a working Home and End key.
  * CGDB fully supports the use of maps now. The feature is similar in
    nature to the vim map feature.  It supports map, unmap, imap
    and iunmap. The map/unmap work in CGDB mode and the imap/iunmap
    work in GDB mode.
  * Added the cgdbmodekey configuration option. This allows the user to
    change the key that switches them from GDB mode to CGDB mode. The
    default value is the Escape key. This is useful for users that want
    to use readline in vi-mode.
  * Fixed a bug in CGDB where the Insert and Delete keys were not
    recognized properly all of the time.
* Thu Mar 19 2009 puzel@suse.cz
- prepare for contrib
* Fri Jul 18 2008 bwalle@suse.de
- change source file format to bzip2
* Thu Jul 17 2008 bwalle@suse.de
- initial package
